@@ -20,31 +20,29 @@
 
 #include "format.h"
 
-#include "ustring.h"
-
-
 using namespace Swinder;
 
 class FormatFont::Private
 {
 public:
-bool null : 1 ;
-bool bold  : 1;
-bool italic : 1;
-bool underline : 1;
-bool strikeout : 1;
-bool subscript : 1;
-bool superscript : 1;
-    UString fontFamily;
+    bool null : 1 ;
+    bool bold  : 1;
+    bool italic : 1;
+    bool underline : 1;
+    bool strikeout : 1;
+    bool subscript : 1;
+    bool superscript : 1;
+    QString fontFamily;
     double fontSize;
     Color color;
 };
 
 FormatFont::FormatFont()
 {
+    static const QString arial("Arial");
     d = new FormatFont::Private();
     d->null        = true;
-    d->fontFamily  = "Arial";
+    d->fontFamily  = arial;
     d->fontSize    = 11;
     d->bold        = false;
     d->italic      = false;
@@ -91,12 +89,12 @@ bool FormatFont::isNull() const
     return d->null;
 }
 
-UString FormatFont::fontFamily() const
+QString FormatFont::fontFamily() const
 {
     return d->fontFamily;
 }
 
-void FormatFont::setFontFamily(const UString& fontFamily)
+void FormatFont::setFontFamily(const QString& fontFamily)
 {
     d->fontFamily = fontFamily;
     d->null = false;
@@ -638,14 +636,15 @@ public:
     FormatAlignment alignment;
     FormatBorders borders;
     FormatBackground background;
-    UString valueFormat;
+    QString valueFormat;
 };
 
 // create an empty format
 Format::Format()
 {
+    static const QString general("General");
     d = new Format::Private;
-    d->valueFormat = "General";
+    d->valueFormat = general;
 }
 
 // destructor
@@ -728,12 +727,12 @@ void Format::setBackground(const FormatBackground& background)
     d->background = background;
 }
 
-UString Format::valueFormat() const
+QString Format::valueFormat() const
 {
     return d->valueFormat;
 }
 
-void Format::setValueFormat(const UString& valueFormat)
+void Format::setValueFormat(const QString& valueFormat)
 {
     d->valueFormat = valueFormat;
 }
