@@ -59,6 +59,7 @@
 #include <kspread/StyleManager.h>
 #include <kspread/Validity.h>
 #include <kspread/Value.h>
+#include <kspread/ValueParser.h>
 
 #define SECSPERDAY (24 * 60 * 60)
 
@@ -327,6 +328,8 @@ void OpenCalcImport::convertFormula(QString & text, QString const & f) const
 
 bool OpenCalcImport::readCells(KoXmlElement & rowNode, Sheet  * table, int row, int & columns)
 {
+    ValueParser *const parser = table->map()->parser();
+
     bool ok = true;
     int spanC = 1;
     int spanR = 1;
@@ -480,7 +483,7 @@ bool OpenCalcImport::readCells(KoXmlElement & rowNode, Sheet  * table, int row,
         }
         if (e.hasAttributeNS(ooNS::table, "validation-name")) {
             kDebug(30518) << " Celle has a validation :" << e.attributeNS(ooNS::table, "validation-name", QString());
-            loadOasisValidation(Cell(table, columns, row).validity(), e.attributeNS(ooNS::table, "validation-name", QString()));
+            loadOasisValidation(Cell(table, columns, row).validity(), e.attributeNS(ooNS::table, "validation-name", QString()), parser);
         }
         if (e.hasAttributeNS(ooNS::table, "value-type")) {
             if (!cell)
@@ -509,101 +512,100 @@ bool OpenCalcImport::readCells(KoXmlElement & rowNode, Sheet  * table, int row,
                         style.setFormatType(Format::Money);
                     }
                 }
-            } else
-                if (type == "percentage") {
-                    dv = value.toDouble(&ok);
-                    if (ok) {
-                        if (!isFormula)
-                            cell.setValue(Value(dv));
-                        //TODO fixme
-                        //cell.setFactor( 100 );
-                        // TODO: replace with custom...
-                        style.setFormatType(Format::Percentage);
-                    }
-                } else if (type == "boolean") {
-                    if (value.isEmpty())
-                        value = e.attributeNS(ooNS::table, "boolean-value", QString());
-
-                    kDebug(30518) << "Type: boolean";
-                    if (value == "true")
-                        cell.setValue(Value(true));
-                    else
-                        cell.setValue(Value(false));
-                    ok = true;
-                    style.setFormatType(Format::Custom);
-                } else if (type == "date") {
-                    if (value.isEmpty())
-                        value = e.attributeNS(ooNS::table, "date-value", QString());
-                    kDebug(30518) << "Type: date, value:" << value;
-
-                    // "1980-10-15"
-                    int year = 0, month = 0, day = 0;
-                    ok = false;
-
-                    int p1 = value.indexOf('-');
-                    if (p1 > 0)
-                        year  = value.left(p1).toInt(&ok);
-
-                    kDebug(30518) << "year:" << value.left(p1);
-
-                    int p2 = value.indexOf('-', ++p1);
-
-                    if (ok)
-                        month = value.mid(p1, p2 - p1).toInt(&ok);
-
-                    kDebug(30518) << "month:" << value.mid(p1, p2 - p1);
-
-                    if (ok)
-                        day = value.right(value.length() - p2 - 1).toInt(&ok);
-
-                    kDebug(30518) << "day:" << value.right(value.length() - p2);
-
-                    if (ok) {
-                        QDateTime dt(QDate(year, month, day));
-                        //            KSpreadValue kval( dt );
-                        // cell.setValue( kval );
-                        cell.setValue(Value(QDate(year, month, day), cell.sheet()->map()->calculationSettings()));
-                        kDebug(30518) << "Set QDate:" << year << " -" << month << " -" << day;
-                    }
-                } else if (type == "time") {
-                    if (value.isEmpty())
-                        value = e.attributeNS(ooNS::table, "time-value", QString());
-
-                    kDebug(30518) << "Type: time:" << value;
-                    // "PT15H10M12S"
-                    int hours = 0, minutes = 0, seconds = 0;
-                    int l = value.length();
-                    QString num;
-
-                    for (int i = 0; i < l; ++i) {
-                        if (value[i].isNumber()) {
-                            num += value[i];
-                            continue;
-                        } else if (value[i] == 'H')
-                            hours   = num.toInt(&ok);
-                        else if (value[i] == 'M')
-                            minutes = num.toInt(&ok);
-                        else if (value[i] == 'S')
-                            seconds = num.toInt(&ok);
-                        else
-                            continue;
-
-                        kDebug(30518) << "Num:" << num;
-
-                        num = "";
-                        if (!ok)
-                            break;
-                    }
-
-                    kDebug(30518) << "Hours:" << hours << "," << minutes << "," << seconds;
-
-                    if (ok) {
-                        // KSpreadValue kval( timeToNum( hours, minutes, seconds ) );
-                        // cell.setValue( kval );
-                        cell.setValue(Value(QTime(hours % 24, minutes, seconds), cell.sheet()->map()->calculationSettings()));
-                        style.setFormatType(Format::Custom);
-                    }
+            } else if (type == "percentage") {
+                dv = value.toDouble(&ok);
+                if (ok) {
+                    if (!isFormula)
+                        cell.setValue(Value(dv));
+                    //TODO fixme
+                    //cell.setFactor( 100 );
+                    // TODO: replace with custom...
+                    style.setFormatType(Format::Percentage);
                 }
+            } else if (type == "boolean") {
+                if (value.isEmpty())
+                    value = e.attributeNS(ooNS::table, "boolean-value", QString());
+
+                kDebug(30518) << "Type: boolean";
+                if (value == "true")
+                    cell.setValue(Value(true));
+                else
+                    cell.setValue(Value(false));
+                ok = true;
+                style.setFormatType(Format::Custom);
+            } else if (type == "date") {
+                if (value.isEmpty())
+                    value = e.attributeNS(ooNS::table, "date-value", QString());
+                kDebug(30518) << "Type: date, value:" << value;
+
+                // "1980-10-15"
+                int year = 0, month = 0, day = 0;
+                ok = false;
+
+                int p1 = value.indexOf('-');
+                if (p1 > 0)
+                    year  = value.left(p1).toInt(&ok);
+
+                kDebug(30518) << "year:" << value.left(p1);
+
+                int p2 = value.indexOf('-', ++p1);
+
+                if (ok)
+                    month = value.mid(p1, p2 - p1).toInt(&ok);
+
+                kDebug(30518) << "month:" << value.mid(p1, p2 - p1);
+
+                if (ok)
+                    day = value.right(value.length() - p2 - 1).toInt(&ok);
+
+                kDebug(30518) << "day:" << value.right(value.length() - p2);
+
+                if (ok) {
+                    QDateTime dt(QDate(year, month, day));
+                    //            KSpreadValue kval( dt );
+                    // cell.setValue( kval );
+                    cell.setValue(Value(QDate(year, month, day), cell.sheet()->map()->calculationSettings()));
+                    kDebug(30518) << "Set QDate:" << year << " -" << month << " -" << day;
+                }
+            } else if (type == "time") {
+                if (value.isEmpty())
+                    value = e.attributeNS(ooNS::table, "time-value", QString());
+
+                kDebug(30518) << "Type: time:" << value;
+                // "PT15H10M12S"
+                int hours = 0, minutes = 0, seconds = 0;
+                int l = value.length();
+                QString num;
+
+                for (int i = 0; i < l; ++i) {
+                    if (value[i].isNumber()) {
+                        num += value[i];
+                        continue;
+                    } else if (value[i] == 'H')
+                        hours   = num.toInt(&ok);
+                    else if (value[i] == 'M')
+                        minutes = num.toInt(&ok);
+                    else if (value[i] == 'S')
+                        seconds = num.toInt(&ok);
+                    else
+                        continue;
+
+                    kDebug(30518) << "Num:" << num;
+
+                    num = "";
+                    if (!ok)
+                        break;
+                }
+
+                kDebug(30518) << "Hours:" << hours << "," << minutes << "," << seconds;
+
+                if (ok) {
+                    // KSpreadValue kval( timeToNum( hours, minutes, seconds ) );
+                    // cell.setValue( kval );
+                    cell.setValue(Value(QTime(hours % 24, minutes, seconds), cell.sheet()->map()->calculationSettings()));
+                    style.setFormatType(Format::Custom);
+                }
+            }
 
             cell.setStyle(style);
             if (!ok)   // just in case we couldn't set the value directly
@@ -660,7 +662,8 @@ void OpenCalcImport::loadCondition(const Cell& cell, const KoXmlElement &propert
 void OpenCalcImport::loadOasisCondition(const Cell& cell, const KoXmlElement &property)
 {
     KoXmlElement elementItem(property);
-    //StyleManager * manager = cell.sheet()->map()->styleManager();
+    Map *const map = cell.sheet()->map();
+    ValueParser *const parser = map->parser();
 
     QLinkedList<Conditional> cond;
     while (!elementItem.isNull()) {
@@ -670,11 +673,11 @@ void OpenCalcImport::loadOasisCondition(const Cell& cell, const KoXmlElement &pr
             bool ok = true;
             kDebug(30518) << "elementItem.attribute(style:condition ) :" << elementItem.attributeNS(ooNS::style, "condition", QString());
             Conditional newCondition;
-            loadOasisConditionValue(elementItem.attributeNS(ooNS::style, "condition", QString()), newCondition);
+            loadOasisConditionValue(elementItem.attributeNS(ooNS::style, "condition", QString()), newCondition, parser);
             if (elementItem.hasAttributeNS(ooNS::style, "apply-style-name")) {
                 kDebug(30518) << "elementItem.attribute( style:apply-style-name ) :" << elementItem.attributeNS(ooNS::style, "apply-style-name", QString());
-                newCondition.styleName = new QString(elementItem.attributeNS(ooNS::style, "apply-style-name", QString()));
-                ok = true;
+                newCondition.styleName = elementItem.attributeNS(ooNS::style, "apply-style-name", QString());
+                ok = !newCondition.styleName.isEmpty();
             }
 
             if (ok)
@@ -691,12 +694,13 @@ void OpenCalcImport::loadOasisCondition(const Cell& cell, const KoXmlElement &pr
     }
 }
 
-void OpenCalcImport::loadOasisConditionValue(const QString &styleCondition, Conditional &newCondition)
+void OpenCalcImport::loadOasisConditionValue(const QString &styleCondition, Conditional &newCondition,
+        const ValueParser *parser)
 {
     QString val(styleCondition);
     if (val.contains("cell-content()")) {
         val = val.remove("cell-content()");
-        loadOasisCondition(val, newCondition);
+        loadOasisCondition(val, newCondition, parser);
     }
     //GetFunction ::= cell-content-is-between(Value, Value) | cell-content-is-not-between(Value, Value)
     //for the moment we support just int/double value, not text/date/time :(
@@ -704,21 +708,26 @@ void OpenCalcImport::loadOasisConditionValue(const QString &styleCondition, Cond
         val = val.remove("cell-content-is-between(");
         val = val.remove(')');
         QStringList listVal = val.split(',');
-        loadOasisValidationValue(listVal, newCondition);
+        kDebug(30518) << " listVal[0] :" << listVal[0] << " listVal[1] :" << listVal[1];
+        newCondition.value1 = parser->parse(listVal[0]);
+        newCondition.value2 = parser->parse(listVal[1]);
         newCondition.cond = Conditional::Between;
     }
     if (val.contains("cell-content-is-not-between(")) {
         val = val.remove("cell-content-is-not-between(");
         val = val.remove(')');
         QStringList listVal = val.split(',');
-        loadOasisValidationValue(listVal, newCondition);
+        kDebug(30518) << " listVal[0] :" << listVal[0] << " listVal[1] :" << listVal[1];
+        newCondition.value1 = parser->parse(listVal[0]);
+        newCondition.value2 = parser->parse(listVal[1]);
         newCondition.cond = Conditional::Different;
     }
 
 }
 
 
-void OpenCalcImport::loadOasisCondition(QString &valExpression, Conditional &newCondition)
+void OpenCalcImport::loadOasisCondition(QString &valExpression, Conditional &newCondition,
+                                        const ValueParser *parser)
 {
     QString value;
     if (valExpression.indexOf("<=") == 0) {
@@ -743,44 +752,9 @@ void OpenCalcImport::loadOasisCondition(QString &valExpression, Conditional &new
     } else
         kDebug(30518) << " I don't know how to parse it :" << valExpression;
     kDebug(30518) << " value :" << value;
-    bool ok = false;
-    newCondition.val1 = value.toDouble(&ok);
-    if (!ok) {
-        newCondition.val1 = value.toInt(&ok);
-        if (!ok) {
-            newCondition.strVal1 = new QString(value);
-            kDebug(30518) << " Try to parse this value :" << value;
-        }
-
-    }
+    newCondition.value1 = parser->parse(value);
 }
 
-
-void OpenCalcImport::loadOasisValidationValue(const QStringList &listVal, Conditional &newCondition)
-{
-    bool ok = false;
-    kDebug(30518) << " listVal[0] :" << listVal[0] << " listVal[1] :" << listVal[1];
-
-    newCondition.val1 = listVal[0].toDouble(&ok);
-    if (!ok) {
-        newCondition.val1 = listVal[0].toInt(&ok);
-        if (!ok) {
-            newCondition.strVal1 = new QString(listVal[0]);
-            kDebug(30518) << " Try to parse this value :" << listVal[0];
-        }
-    }
-    ok = false;
-    newCondition.val2 = listVal[1].toDouble(&ok);
-    if (!ok) {
-        newCondition.val2 = listVal[1].toInt(&ok);
-        if (!ok) {
-            newCondition.strVal2 = new QString(listVal[1]);
-            kDebug(30518) << " Try to parse this value :" << listVal[1];
-        }
-    }
-}
-
-
 bool OpenCalcImport::readRowsAndCells(KoXmlElement & content, Sheet * table)
 {
     kDebug(30518) << "Reading in rows";
@@ -1229,7 +1203,7 @@ bool OpenCalcImport::parseBody(int numOfTables)
         return false;
 
     loadOasisAreaName(body.toElement());
-    loadOasisCellValidation(body.toElement());
+    loadOasisCellValidation(body.toElement(), m_doc->map()->parser());
 
     Sheet * table;
     KoXmlNode sheet = KoXml::namedItemNS(body, ooNS::table, "table");
@@ -1426,7 +1400,7 @@ void OpenCalcImport::loadOasisAreaName(const KoXmlElement&body)
     }
 }
 
-void OpenCalcImport::loadOasisCellValidation(const KoXmlElement&body)
+void OpenCalcImport::loadOasisCellValidation(const KoXmlElement&body, const ValueParser *parser)
 {
     KoXmlNode validation = KoXml::namedItemNS(body, ooNS::table, "content-validations");
     if (!validation.isNull()) {
@@ -2098,7 +2072,7 @@ bool OpenCalcImport::createStyleMap(KoXmlDocument const & styles)
     return true;
 }
 
-void OpenCalcImport::loadOasisValidation(Validity validity, const QString& validationName)
+void OpenCalcImport::loadOasisValidation(Validity validity, const QString& validationName, const ValueParser *parser)
 {
     kDebug(30518) << "validationName:" << validationName;
     KoXmlElement element = m_validationList[validationName];
@@ -2124,7 +2098,7 @@ void OpenCalcImport::loadOasisValidation(Validity validity, const QString& valid
             kDebug(30518) << " valExpression = :" << valExpression;
             validity.setRestriction(Validity::TextLength);
 
-            loadOasisValidationCondition(validity, valExpression);
+            loadOasisValidationCondition(validity, valExpression, parser);
         }
         //cell-content-text-length-is-between(Value, Value) | cell-content-text-length-is-not-between(Value, Value)
         else if (valExpression.contains("cell-content-text-length-is-between")) {
@@ -2134,7 +2108,7 @@ void OpenCalcImport::loadOasisValidation(Validity validity, const QString& valid
             kDebug(30518) << " valExpression :" << valExpression;
             valExpression = valExpression.remove(')');
             QStringList listVal = valExpression.split(',');
-            loadOasisValidationValue(validity, listVal);
+            loadOasisValidationValue(validity, listVal, parser);
         } else if (valExpression.contains("cell-content-text-length-is-not-between")) {
             validity.setRestriction(Validity::TextLength);
             validity.setCondition(Conditional::Different);
@@ -2143,7 +2117,7 @@ void OpenCalcImport::loadOasisValidation(Validity validity, const QString& valid
             valExpression = valExpression.remove(')');
             kDebug(30518) << " valExpression :" << valExpression;
             QStringList listVal = valExpression.split(',');
-            loadOasisValidationValue(validity, listVal);
+            loadOasisValidationValue(validity, listVal, parser);
 
         }
         //TrueFunction ::= cell-content-is-whole-number() | cell-content-is-decimal-number() | cell-content-is-date() | cell-content-is-time()
@@ -2165,7 +2139,7 @@ void OpenCalcImport::loadOasisValidation(Validity validity, const QString& valid
 
             if (valExpression.contains("cell-content()")) {
                 valExpression = valExpression.remove("cell-content()");
-                loadOasisValidationCondition(validity, valExpression);
+                loadOasisValidationCondition(validity, valExpression, parser);
             }
             //GetFunction ::= cell-content-is-between(Value, Value) | cell-content-is-not-between(Value, Value)
             //for the moment we support just int/double value, not text/date/time :(
@@ -2173,7 +2147,7 @@ void OpenCalcImport::loadOasisValidation(Validity validity, const QString& valid
                 valExpression = valExpression.remove("cell-content-is-between(");
                 valExpression = valExpression.remove(')');
                 QStringList listVal = valExpression.split(',');
-                loadOasisValidationValue(validity, listVal);
+                loadOasisValidationValue(validity, listVal, parser);
 
                 validity.setCondition(Conditional::Between);
             }
@@ -2181,7 +2155,7 @@ void OpenCalcImport::loadOasisValidation(Validity validity, const QString& valid
                 valExpression = valExpression.remove("cell-content-is-not-between(");
                 valExpression = valExpression.remove(')');
                 QStringList listVal = valExpression.split(',');
-                loadOasisValidationValue(validity, listVal);
+                loadOasisValidationValue(validity, listVal, parser);
                 validity.setCondition(Conditional::Different);
             }
         }
@@ -2231,46 +2205,17 @@ void OpenCalcImport::loadOasisValidation(Validity validity, const QString& valid
     }
 }
 
-void OpenCalcImport::loadOasisValidationValue(Validity validity, const QStringList &listVal)
+void OpenCalcImport::loadOasisValidationValue(Validity validity, const QStringList &listVal, const ValueParser *parser)
 {
     bool ok = false;
     kDebug(30518) << " listVal[0] :" << listVal[0] << " listVal[1] :" << listVal[1];
 
-    if (validity.restriction() == Validity::Date) {
-        validity.setMinimumDate(QDate::fromString(listVal[0]));
-        validity.setMaximumDate(QDate::fromString(listVal[1]));
-    } else if (validity.restriction() == Validity::Time) {
-        validity.setMinimumTime(QTime::fromString(listVal[0]));
-        validity.setMaximumTime(QTime::fromString(listVal[1]));
-    } else {
-        validity.setMinimumValue(listVal[0].toDouble(&ok));
-        if (!ok) {
-            validity.setMinimumValue(listVal[0].toInt(&ok));
-            if (!ok)
-                kDebug(30518) << " Try to parse this value :" << listVal[0];
-
-#if 0
-            if (!ok)
-                validity.setMinimumValue(listVal[0]);
-#endif
-        }
-        ok = false;
-        validity.setMaximumValue(listVal[1].toDouble(&ok));
-        if (!ok) {
-            validity.setMaximumValue(listVal[1].toInt(&ok));
-            if (!ok)
-                kDebug(30518) << " Try to parse this value :" << listVal[1];
-
-#if 0
-            if (!ok)
-                validity.setMaximumValue(listVal[1]);
-#endif
-        }
-    }
+    validity.setMinimumValue(parser->parse(listVal[0]));
+    validity.setMaximumValue(parser->parse(listVal[1]));
 }
 
 
-void OpenCalcImport::loadOasisValidationCondition(Validity validity, QString &valExpression)
+void OpenCalcImport::loadOasisValidationCondition(Validity validity, QString &valExpression, const ValueParser *parser)
 {
     QString value;
     if (valExpression.contains("<=")) {
@@ -2294,25 +2239,9 @@ void OpenCalcImport::loadOasisValidationCondition(Validity validity, QString &va
         validity.setCondition(Conditional::Equal);
     } else
         kDebug(30518) << " I don't know how to parse it :" << valExpression;
-    kDebug(30518) << " value :" << value;
-    if (validity.restriction() == Validity::Date) {
-        validity.setMinimumDate(QDate::fromString(value));
-    } else if (validity.restriction() == Validity::Date) {
-        validity.setMinimumTime(QTime::fromString(value));
-    } else {
-        bool ok = false;
-        validity.setMinimumValue(value.toDouble(&ok));
-        if (!ok) {
-            validity.setMinimumValue(value.toInt(&ok));
-            if (!ok)
-                kDebug(30518) << " Try to parse this value :" << value;
 
-#if 0
-            if (!ok)
-                validity.setMinimumValue(value);
-#endif
-        }
-    }
+    kDebug(30518) << " value :" << value;
+    validity.setMinimumValue(parser->parse(value));
 }
 
 
