@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright 2007 Alfredo Beaumont Sainz <alfredo.beaumont@gmail.com>
+   Copyright 2007-2009 Alfredo Beaumont Sainz <alfredo.beaumont@gmail.com>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,7 +21,6 @@
 
 #include <QtTest/QtTest>
 #include <QtCore/QBuffer>
-#include <QtXml/QDomDocument>
 
 #include <KoXmlWriter.h>
 #include <KoXmlReader.h>
@@ -95,8 +94,9 @@ void TestLoadAndSave::identifierElement_data()
     // See section 2.4.6 Collapsing Whitespace in Input
     addRow( "<mi> a b c </mi>",
             "<mi>a b c</mi>" );
-    addRow( "<mi> x <mglyph index=\"99\" alt=\"c\"> d </mi>",
-            "<mi>x <mglyph index=\"99\" alt=\"c\"> d</mi>" );
+    // Since newline is hardcoded in KoXmlWriter and it's sematically equivalent, add it to expected result
+    addRow( "<mi> x <mglyph fontfamily=\"testfont\" index=\"99\" alt=\"c\"/> d </mi>",
+            "<mi>x \n <mglyph fontfamily=\"testfont\" index=\"99\" alt=\"c\"/> d</mi>" );
     addRow( "<mi> x  y    z   </mi>",
             "<mi>x y z</mi>" );
 
@@ -256,17 +256,85 @@ void TestLoadAndSave::textElement_data()
     QTest::addColumn<QString>("input");
     QTest::addColumn<QString>("output");
 
-    // TODO
-    addRow( "" );
+    addRow( "<mtext></mtext>" );
+    addRow( "<mtext>text</mtext>" );
+    addRow( "<mtext> text </mtext>",
+            "<mtext>text</mtext>");
+    addRow( "<mtext> Theorem 1: </mtext>",
+            "<mtext>Theorem 1:</mtext>" );
+    addRow( "<mtext> &ThinSpace; </mtext>",
+            "<mtext>&ThinSpace;</mtext>" );
+    addRow( "<mtext> &ThickSpace;&ThickSpace; </mtext>",
+            "<mtext>&ThickSpace;&ThickSpace;</mtext>" );
+    addRow( "<mtext> /* a comment */ </mtext>",
+            "<mtext>/* a comment */</mtext>" );
 }
 
+
+
 void TestLoadAndSave::spaceElement_data()
 {
     QTest::addColumn<QString>("input");
     QTest::addColumn<QString>("output");
 
-    // TODO
-    addRow( "" );
+    addRow( "<mspace/>" );
+
+    // Check operator attributes. Sefction 3.2.7.2
+
+    addRow( "<mspace width=\"10em\"/>" );
+    addRow( "<mspace width=\"10ex\"/>" );
+    addRow( "<mspace width=\"10px\"/>" );
+    addRow( "<mspace width=\"10in\"/>" );
+    addRow( "<mspace width=\"10cm\"/>" );
+    addRow( "<mspace width=\"10mm\"/>" );
+    addRow( "<mspace width=\"10pt\"/>" );
+    addRow( "<mspace width=\"10pc\"/>" );
+    addRow( "<mspace width=\"90%\"/>" );
+    addRow( "<mspace width=\"1.2\"/>" );
+    addRow( "<mspace width=\"veryverythinmathspace\"/>" );
+    addRow( "<mspace width=\"verythinmathspace\"/>" );
+    addRow( "<mspace width=\"thinmathspace\"/>" );
+    addRow( "<mspace width=\"mediummathspace\"/>" );
+    addRow( "<mspace width=\"thickmathspace\"/>" );
+    addRow( "<mspace width=\"verythickmathspace\"/>" );
+    addRow( "<mspace width=\"veryverythickmathspace\"/>" );
+    addRow( "<mspace width=\"negativeveryverythinmathspace\"/>" );
+    addRow( "<mspace width=\"negativeverythinmathspace\"/>" );
+    addRow( "<mspace width=\"negativethinmathspace\"/>" );
+    addRow( "<mspace width=\"negativemediummathspace\"/>" );
+    addRow( "<mspace width=\"negativethickmathspace\"/>" );
+    addRow( "<mspace width=\"negativeverythickmathspace\"/>" );
+    addRow( "<mspace width=\"negativeveryverythickmathspace\"/>" );
+
+    addRow( "<mspace height=\"10em\"/>" );
+    addRow( "<mspace height=\"10ex\"/>" );
+    addRow( "<mspace height=\"10px\"/>" );
+    addRow( "<mspace height=\"10in\"/>" );
+    addRow( "<mspace height=\"10cm\"/>" );
+    addRow( "<mspace height=\"10mm\"/>" );
+    addRow( "<mspace height=\"10pt\"/>" );
+    addRow( "<mspace height=\"10pc\"/>" );
+    addRow( "<mspace height=\"90%\"/>" );
+    addRow( "<mspace height=\"1.2\"/>" );
+
+    addRow( "<mspace depth=\"10em\"/>" );
+    addRow( "<mspace depth=\"10ex\"/>" );
+    addRow( "<mspace depth=\"10px\"/>" );
+    addRow( "<mspace depth=\"10in\"/>" );
+    addRow( "<mspace depth=\"10cm\"/>" );
+    addRow( "<mspace depth=\"10mm\"/>" );
+    addRow( "<mspace depth=\"10pt\"/>" );
+    addRow( "<mspace depth=\"10pc\"/>" );
+    addRow( "<mspace depth=\"90%\"/>" );
+    addRow( "<mspace depth=\"1.2\"/>" );
+
+    addRow( "<mspace linebreak=\"auto\"/>" );
+    addRow( "<mspace linebreak=\"newline\"/>" );
+    addRow( "<mspace linebreak=\"indentingnewline\"/>" );
+    addRow( "<mspace linebreak=\"nobreak\"/>" );
+    addRow( "<mspace linebreak=\"goodbreak\"/>" );
+    addRow( "<mspace linebreak=\"badbreak\"/>" );
+
 }
 
 void TestLoadAndSave::stringElement_data()
@@ -313,7 +381,7 @@ void TestLoadAndSave::mathVariant_data()
      */
     addRow( "<mi mathvariant=\"invalid\">x</mi>",
             "<mi>x</mi>");
-    
+
     /*
      * It's better to store attribute names and values lowercase and avoid
      * having to check whether it's upper or lower case on a per-use case,
@@ -356,7 +424,7 @@ void TestLoadAndSave::mathSize_data()
      */
     addRow( "<mi mathsize=\"invalid\">x</mi>",
             "<mi>x</mi>");
-    
+
     /*
      * It's better to store attribute names and values lowercase and avoid
      * having to check whether it's upper or lower case on a per-use case,
@@ -393,7 +461,7 @@ void TestLoadAndSave::mathColor_data()
             "<mi>x</mi>");
     addRow( "<mi mathcolor=\"#abcdefg\">x</mi>",
             "<mi>x</mi>");
-    
+
     /*
      * It's better to store attribute names and values lowercase and avoid
      * having to check whether it's upper or lower case on a per-use case,
@@ -432,7 +500,7 @@ void TestLoadAndSave::mathBackground_data()
             "<mi>x</mi>");
     addRow( "<mi mathbackground=\"#abcdefg\">x</mi>",
             "<mi>x</mi>");
-    
+
     /*
      * It's better to store attribute names and values lowercase and avoid
      * having to check whether it's upper or lower case on a per-use case,
@@ -474,7 +542,7 @@ void TestLoadAndSave::fontSize_data()
      */
     addRow( "<mi fontsize=\"invalid\">x</mi>",
             "<mi>x</mi>");
-    
+
     /*
      * It's better to store attribute names and values lowercase and avoid
      * having to check whether it's upper or lower case on a per-use case,
@@ -506,7 +574,7 @@ void TestLoadAndSave::fontWeight_data()
      */
     addRow( "<mi fontweight=\"invalid\">x</mi>",
             "<mi>x</mi>");
-    
+
     /*
      * It's better to store attribute names and values lowercase and avoid
      * having to check whether it's upper or lower case on a per-use case,
@@ -538,7 +606,7 @@ void TestLoadAndSave::fontStyle_data()
      */
     addRow( "<mi fontstyle=\"invalid\">x</mi>",
             "<mi>x</mi>");
-    
+
     /*
      * It's better to store attribute names and values lowercase and avoid
      * having to check whether it's upper or lower case on a per-use case,
@@ -575,7 +643,7 @@ void TestLoadAndSave::color_data()
             "<mi>x</mi>");
     addRow( "<mi color=\"#abcdefg\">x</mi>",
             "<mi>x</mi>");
-    
+
     /*
      * It's better to store attribute names and values lowercase and avoid
      * having to check whether it's upper or lower case on a per-use case,
@@ -610,12 +678,8 @@ void TestLoadAndSave::fractionElement_data()
     // TODO
     addRow( "<mfrac><mi>x</mi><mi>y</mi></mfrac>",
             "<mfrac>\n"
-            " <mrow>\n"
-            "  <mi>x</mi>\n"
-            " </mrow>\n"
-            " <mrow>\n"
-            "  <mi>y</mi>\n"
-            " </mrow>\n"
+            " <mi>x</mi>\n"
+            " <mi>y</mi>\n"
             "</mfrac>");
 }
 
@@ -624,8 +688,6 @@ void TestLoadAndSave::rootElement_data()
     QTest::addColumn<QString>("input");
     QTest::addColumn<QString>("output");
 
-    addRow( "<msqrt><mi>x</mi></msqrt>" );
-
     addRow( "<mroot><mi>x</mi><mn>2</mn></mroot>" );
 }
 
@@ -635,7 +697,7 @@ void TestLoadAndSave::styleElement_data()
     QTest::addColumn<QString>("output");
 
     // TODO
-    addRow( "" );
+    addRow( "<mstyle></mstyle>" );
 }
 
 void TestLoadAndSave::errorElement_data()
@@ -644,7 +706,7 @@ void TestLoadAndSave::errorElement_data()
     QTest::addColumn<QString>("output");
 
     // TODO
-    addRow( "" );
+    addRow( "<merror></merror>" );
 }
 
 void TestLoadAndSave::paddedElement_data()
@@ -653,7 +715,7 @@ void TestLoadAndSave::paddedElement_data()
     QTest::addColumn<QString>("output");
 
     // TODO
-    addRow( "" );
+    addRow( "<mpadded></mpadded>" );
 }
 
 void TestLoadAndSave::phantomElement_data()
@@ -662,7 +724,7 @@ void TestLoadAndSave::phantomElement_data()
     QTest::addColumn<QString>("output");
 
     // TODO
-    addRow( "" );
+    addRow( "<mphantom></mphantom>" );
 }
 
 void TestLoadAndSave::fencedElement_data()
@@ -671,7 +733,7 @@ void TestLoadAndSave::fencedElement_data()
     QTest::addColumn<QString>("output");
 
     // TODO
-    addRow( "" );
+    addRow( "<mfenced></mfenced>" );
 }
 
 void TestLoadAndSave::encloseElement_data()
@@ -680,7 +742,7 @@ void TestLoadAndSave::encloseElement_data()
     QTest::addColumn<QString>("output");
 
     // TODO
-    addRow( "" );
+    addRow( "<menclose></menclose>" );
 }
 
 void TestLoadAndSave::subElement_data()
@@ -689,7 +751,7 @@ void TestLoadAndSave::subElement_data()
     QTest::addColumn<QString>("output");
 
     // TODO
-    addRow( "" );
+    addRow( "<msub></msub>" );
 }
 
 void TestLoadAndSave::supElement_data()
@@ -698,7 +760,7 @@ void TestLoadAndSave::supElement_data()
     QTest::addColumn<QString>("output");
 
     // TODO
-    addRow( "" );
+    addRow( "<msup></msup>" );
 }
 
 void TestLoadAndSave::subsupElement_data()
@@ -707,7 +769,7 @@ void TestLoadAndSave::subsupElement_data()
     QTest::addColumn<QString>("output");
 
     // TODO
-    addRow( "" );
+    addRow( "<" );
 }
 
 void TestLoadAndSave::underElement_data()
@@ -798,7 +860,7 @@ void TestLoadAndSave::identifierElement()
 
 void TestLoadAndSave::numberElement()
 {
-    test( new IdentifierElement );
+    test( new NumberElement );
 }
 
 void TestLoadAndSave::operatorElement()
@@ -948,22 +1010,22 @@ void TestLoadAndSave::multiscriptsElement()
 
 void TestLoadAndSave::tableElement()
 {
-    test( new MatrixElement );
+    test( new TableElement );
 }
 
 void TestLoadAndSave::trElement()
 {
-    test( new MatrixRowElement );
+    test( new TableRowElement );
 }
 
 void TestLoadAndSave::labeledtrElement()
 {
-    test( new MatrixRowElement );
+    test( new TableRowElement );
 }
 
 void TestLoadAndSave::tdElement()
 {
-    test( new MatrixEntryElement );
+    test( new TableEntryElement );
 }
 
 void TestLoadAndSave::actionElement()
