@@ -200,7 +200,8 @@ void Style::loadAttributes(const QList<SharedSubStyle>& subStyles)
 }
 
 void Style::loadOdfStyle(KoOdfStylesReader& stylesReader, const KoXmlElement& element,
-                         Conditions& conditions, const StyleManager* styleManager)
+                         Conditions& conditions, const StyleManager* styleManager,
+                         const ValueParser *parser)
 {
     // NOTE Stefan: Do not fill the style stack with the parent styles!
     KoStyleStack styleStack;
@@ -215,15 +216,17 @@ void Style::loadOdfStyle(KoOdfStylesReader& stylesReader, const KoXmlElement& el
     KoXmlElement e;
     forEachElement(e, element) {
         if (e.namespaceURI() == KoXmlNS::style && e.localName() == "map")
-            conditions.loadOdfConditions(styleManager, e);
+            conditions.loadOdfConditions(e, parser);
     }
 
-    loadOdfDataStyle(stylesReader, element, conditions, styleManager);
+    loadOdfDataStyle(stylesReader, element, conditions, styleManager, parser);
 }
 
 typedef QPair<QString,QString> StringPair;
 
-void Style::loadOdfDataStyle(KoOdfStylesReader& stylesReader, const KoXmlElement& element, Conditions& conditions, const StyleManager* styleManager)
+void Style::loadOdfDataStyle(KoOdfStylesReader& stylesReader, const KoXmlElement& element,
+                             Conditions& conditions, const StyleManager* styleManager,
+                             const ValueParser *parser)
 {
     QString str;
     if (element.hasAttributeNS(KoXmlNS::style, "data-style-name")) {
@@ -239,11 +242,13 @@ void Style::loadOdfDataStyle(KoOdfStylesReader& stylesReader, const KoXmlElement
                     dataStyle = stylesReader.dataFormats()[stylename];
 
                 for (QList<QPair<QString,QString> >::const_iterator it = styleMaps.begin(); it != styleMaps.end(); ++it) {
-                    const Conditional c = conditions.loadOdfCondition(styleManager, it->first, it->second);
-                    if (c.styleName && styleManager->style(*c.styleName) == 0) {
-                        CustomStyle* const s = new CustomStyle(*c.styleName);
-                        const KoOdfNumberStyles::NumericStyleFormat& ds = stylesReader.dataFormats()[*c.styleName];
-                        s->setCustomFormat(ds.formatStr);
+                    const Conditional c = conditions.loadOdfCondition(it->first, it->second, parser);
+                    if (styleManager->style(c.styleName) == 0) {
+                        CustomStyle* const s = new CustomStyle(c.styleName);
+                        if (stylesReader.dataFormats().contains(c.styleName)) {
+                            KoOdfNumberStyles::NumericStyleFormat ds = stylesReader.dataFormats()[c.styleName];
+                            s->setCustomFormat(ds.formatStr);
+                        }
                         const_cast<StyleManager*>(styleManager)->insertStyle(s);
                     }
                 }
@@ -566,7 +571,7 @@ Format::Type Style::dateType(const QString &_f)
     const QString dateFormatShort = convertDateFormat(KGlobal::locale()->dateFormatShort());
     const QString dateFormat = convertDateFormat(KGlobal::locale()->dateFormat());
     QString _format = _f;
-    _format.replace(' ','-');
+    _format.replace(' ', '-');
 
     if (_format == "d-MMM-yy" || _format == "dd-MMM-yy")
         return Format::Date1;
@@ -586,7 +591,7 @@ Format::Type Style::dateType(const QString &_f)
         return Format::Date8;
     else if (_format == "MMMM-yyyy")
         return Format::Date9;
-    else if (_format == "MMMMM-yy")
+    else if (_format == "MMMMM-yy" || _format == "X-yy")
         return Format::Date10;
     else if (_format == "dd/MMM")
         return Format::Date11;
@@ -643,7 +648,7 @@ Format::Type Style::dateType(const QString &_f)
     else if (_format == dateFormat)
         return Format::TextDate;
     else {
-        kDebug() << "Unhandled date format="<<_format;
+        kDebug() << "Unhandled date format=" << _format;
         return Format::ShortDate;
     }
 }
@@ -1261,10 +1266,10 @@ void Style::saveOdfStyle(const QSet<Key>& keysToStore, KoGenStyle &style,
     if (keysToStore.contains(BackgroundColor) && backgroundColor().isValid())
         style.addProperty("fo:background-color", colorName(backgroundColor()));
 
-    if (keysToStore.contains(MultiRow) && keysToStore.contains(MultiRow))
+    if (keysToStore.contains(MultiRow) && wrapText())
         style.addProperty("fo:wrap-option", "wrap");
 
-    if (keysToStore.contains(VerticalText) && keysToStore.contains(VerticalText)) {
+    if (keysToStore.contains(VerticalText) && verticalText()) {
         style.addProperty("style:direction", "ttb");
         style.addProperty("style:rotation-angle", "0");
         style.addProperty("style:rotation-align", "none");
@@ -2732,7 +2737,7 @@ QString CustomStyle::saveOdf(KoGenStyle& style, KoGenStyles &mainStyles,
 
 void CustomStyle::loadOdf(KoOdfStylesReader& stylesReader, const KoXmlElement& style,
                           const QString& name, Conditions& conditions,
-                          const StyleManager* styleManager)
+                          const StyleManager* styleManager, const ValueParser *parser)
 {
     setName(name);
     if (style.hasAttributeNS(KoXmlNS::style, "parent-style-name"))
@@ -2740,7 +2745,7 @@ void CustomStyle::loadOdf(KoOdfStylesReader& stylesReader, const KoXmlElement& s
 
     setType(CUSTOM);
 
-    Style::loadOdfStyle(stylesReader, style, conditions, styleManager);
+    Style::loadOdfStyle(stylesReader, style, conditions, styleManager, parser);
 }
 
 void CustomStyle::save(QDomDocument& doc, QDomElement& styles, const StyleManager* styleManager)
