@@ -19,6 +19,7 @@
 */
 
 // built-in reference functions
+#include "ReferenceModule.h"
 
 #include "Cell.h"
 #include "Region.h"
@@ -28,9 +29,8 @@
 
 #include "CellStorage.h"
 #include "Formula.h"
+#include "Function.h"
 #include "FunctionModuleRegistry.h"
-#include "Functions.h"
-#include "ReferenceModule.h"
 #include "ValueCalc.h"
 #include "ValueConverter.h"
 
@@ -60,46 +60,46 @@ KSPREAD_EXPORT_FUNCTION_MODULE("reference", ReferenceModule)
 
 
 ReferenceModule::ReferenceModule(QObject* parent, const QVariantList&)
-    : FunctionModule(parent)
+        : FunctionModule(parent)
 {
     Function *f;
 
     f = new Function("ADDRESS",  func_address);
     f->setParamCount(2, 5);
-  add(f);
+    add(f);
     f = new Function("AREAS",    func_areas);
     f->setParamCount(1);
     f->setNeedsExtra(true);
     f->setAcceptArray();
-  add(f);
+    add(f);
     f = new Function("CHOOSE",   func_choose);
     f->setParamCount(2, -1);
     f->setAcceptArray();
-  add(f);
+    add(f);
     f = new Function("COLUMN",   func_column);
     f->setParamCount(0, 1);
-  add(f);
+    add(f);
     f = new Function("COLUMNS",  func_columns);
     f->setParamCount(1);
     f->setAcceptArray();
     f->setNeedsExtra(true);
-  add(f);
+    add(f);
     f = new Function("HLOOKUP",  func_hlookup);
     f->setParamCount(3, 4);
     f->setAcceptArray();
-  add(f);
+    add(f);
     f = new Function("INDEX",   func_index);
     f->setParamCount(3);
     f->setAcceptArray();
-  add(f);
+    add(f);
     f = new Function("INDIRECT", func_indirect);
     f->setParamCount(1, 2);
     f->setNeedsExtra(true);
-  add(f);
+    add(f);
     f = new Function("LOOKUP",   func_lookup);
     f->setParamCount(3);
     f->setAcceptArray();
-  add(f);
+    add(f);
     f = new Function("MATCH", func_match);
     f->setParamCount(2, 3);
     f->setAcceptArray();
@@ -108,19 +108,19 @@ ReferenceModule::ReferenceModule(QObject* parent, const QVariantList&)
     f = new Function("MULTIPLE.OPERATIONS", func_multiple_operations);
     f->setParamCount(3, 5);
     f->setNeedsExtra(true);
-  add(f);
+    add(f);
     f = new Function("ROW",      func_row);
     f->setParamCount(0, 1);
-  add(f);
+    add(f);
     f = new Function("ROWS",     func_rows);
     f->setParamCount(1);
     f->setAcceptArray();
     f->setNeedsExtra(true);
-  add(f);
+    add(f);
     f = new Function("VLOOKUP",  func_vlookup);
     f->setParamCount(3, 4);
     f->setAcceptArray();
-  add(f);
+    add(f);
 }
 
 QString ReferenceModule::descriptionFileName() const
