@@ -126,12 +126,12 @@ public:
     // NOTE Stefan: A cell is either obscured by an other one or obscures others itself.
     //              But never both at the same time, so we can share the memory for this.
     union {
-    int obscuringCellX : 16; // KS_colMax
-    int obscuredCellsX : 16; // KS_colMax
+        int obscuringCellX : 16; // KS_colMax
+        int obscuredCellsX : 16; // KS_colMax
     };
     union {
-    int obscuringCellY : 16; // KS_rowMax
-    int obscuredCellsY : 16; // KS_rowMax
+        int obscuringCellY : 16; // KS_rowMax
+        int obscuredCellsY : 16; // KS_rowMax
     };
 
     // This is the text we want to display. Not necessarily the same
@@ -190,8 +190,10 @@ CellView::CellView(SheetView* sheetView, int col, int row)
 
         // use conditional formatting attributes
         Conditions conditions = cell.conditions();
-        if (Style* style = conditions.testConditions(cell, sheetView->sheet()->map()->styleManager()))
-            d->style.merge(*style);
+        const Style conditionalStyle = conditions.testConditions(cell);
+        if (!conditionalStyle.isEmpty()) {
+            d->style.merge(conditionalStyle);
+        }
     }
 
     if (cell.width() != sheetView->sheet()->map()->defaultColumnFormat()->width())
@@ -290,8 +292,16 @@ QRectF CellView::textRect() const
     return QRectF(d->textX, d->textY, d->textWidth, d->textWidth);
 }
 
-QString CellView::testAnchor(const Cell& cell, qreal x, qreal y) const
+QString CellView::testAnchor(SheetView* sheetView, const Cell& cell, qreal x, qreal y) const
 {
+    if (isObscured()) {
+        Sheet* sheet = cell.sheet();
+        Cell otherCell = Cell(sheet, d->obscuringCellX, d->obscuringCellY);
+        const CellView& otherView = sheetView->cellView(otherCell.column(), otherCell.row());
+        if (cell.column() != otherCell.column()) x += sheet->columnPosition(cell.column()) - sheet->columnPosition(otherCell.column());
+        if (cell.row() != otherCell.row()) y += sheet->rowPosition(cell.row()) - sheet->rowPosition(otherCell.row());
+        return otherView.testAnchor(sheetView, otherCell, x, y);
+    }
     if (cell.link().isEmpty())
         return QString();
 
@@ -331,7 +341,7 @@ bool CellView::hitTestFilterButton(const Cell& cell, const QRect& cellRect, cons
 //              coordinates.
 //
 void CellView::paintCellContents(const QRectF& paintRect, QPainter& painter,
-                                 QPaintDevice* paintDevice, const QPointF& coordinate,
+                                 const QPointF& coordinate,
                                  const Cell& cell, SheetView* sheetView)
 {
     if (d->hidden)
@@ -380,7 +390,7 @@ void CellView::paintCellContents(const QRectF& paintRect, QPainter& painter,
             && (!dynamic_cast<QPrinter*>(painter.device()) || style().printText())
             && !(cell.sheet()->isProtected()
                  && style().hideAll())) {
-        paintText(painter, coordinate, paintDevice, cell);
+        paintText(painter, coordinate, cell);
     }
 }
 
@@ -658,7 +668,7 @@ void CellView::paintDefaultBorders(QPainter& painter, const QRectF& paintRect,
         int dt = 0;
         int db = 0;
 
-#if 0
+#if 0 // KSPREAD_WIP_STYLE_BORDER
         if (cellRef.x() > 1) {
             Cell  *cell_west = Cell(cell.sheet(), cellRef.x() - 1,
                                     cellRef.y());
@@ -694,7 +704,7 @@ void CellView::paintDefaultBorders(QPainter& painter, const QRectF& paintRect,
         int dl = 0;
         int dr = 0;
 
-#if 0
+#if 0 // KSPREAD_WIP_STYLE_BORDER
         if (cellRef.y() > 1) {
             Cell  *cell_north = Cell(cell.sheet(), cellRef.x(),
                                      cellRef.y() - 1);
@@ -731,7 +741,7 @@ void CellView::paintDefaultBorders(QPainter& painter, const QRectF& paintRect,
         int dt = 0;
         int db = 0;
 
-#if 0
+#if 0 // KSPREAD_WIP_STYLE_BORDER
         if (cellRef.x() < KS_colMax) {
             Cell  *cell_east = Cell(cell.sheet(), cellRef.x() + 1,
                                     cellRef.y());
@@ -768,7 +778,7 @@ void CellView::paintDefaultBorders(QPainter& painter, const QRectF& paintRect,
     if (paintBorder & BottomBorder) {
         int dl = 0;
         int dr = 0;
-#if 0
+#if 0 // KSPREAD_WIP_STYLE_BORDER
         if (cellRef.y() < KS_rowMax) {
             Cell  *cell_south = Cell(cell.sheet(), cellRef.x(),
                                      cellRef.y() + 1);
@@ -976,10 +986,8 @@ static int fixAngle(int angle) {
 //
 void CellView::paintText(QPainter& painter,
                          const QPointF& coordinate,
-                         QPaintDevice* paintDevice, const Cell& cell)
+                         const Cell& cell)
 {
-    Q_UNUSED(paintDevice);
-
     QColor textColorPrint = d->style.fontColor();
     // Resolve the text color if invalid (=default).
     if (!textColorPrint.isValid()) {
@@ -991,7 +999,6 @@ void CellView::paintText(QPainter& painter,
         QColor bgColor = d->style.backgroundColor();
         if (bgColor.isValid()) {
             qreal contrast = KColorUtils::contrastRatio(bgColor, textColorPrint);
-            kDebug() << bgColor << textColorPrint << contrast;
             if (contrast < 3)
                 textColorPrint = QColor(255 - textColorPrint.red(), 255 - textColorPrint.green(), 255 - textColorPrint.blue());
         }
@@ -1108,15 +1115,15 @@ void CellView::paintText(QPainter& painter,
         qreal space = d->width - d->textWidth;
         if (space > 0) {
             switch (hAlign) {
-                case Style::Center:
-                case Style::HAlignUndefined:
-                    dx += space/2;
-                    break;
-                case Style::Right:
-                    dx += space;
-                    break;
-                default:
-                    break;
+            case Style::Center:
+            case Style::HAlignUndefined:
+                dx += space / 2;
+                break;
+            case Style::Right:
+                dx += space;
+                break;
+            default:
+                break;
             }
         }
         for (int i = 0; i < textLines.count(); ++i) {
@@ -1167,11 +1174,11 @@ void CellView::paintPageBorders(QPainter& painter, const QPointF& coordinate,
     QLineF line;
 
     if (cell.column() >= printRange.left()
-        && cell.column() <= printRange.right() + 1
-        && cell.row() >= printRange.top()
-        && cell.row() <= printRange.bottom() + 1) {
+            && cell.column() <= printRange.right() + 1
+            && cell.row() >= printRange.top()
+            && cell.row() <= printRange.bottom() + 1) {
         if (print->isColumnOnNewPage(cell.column())
-            && cell.row() <= printRange.bottom()) {
+                && cell.row() <= printRange.bottom()) {
             painter.setPen(cell.sheet()->map()->settings()->pageBorderColor());
 
             if (cell.sheet()->layoutDirection() == Qt::RightToLeft)
@@ -1184,7 +1191,7 @@ void CellView::paintPageBorders(QPainter& painter, const QPointF& coordinate,
         }
 
         if (print->isRowOnNewPage(cell.row()) &&
-            (cell.column() <= printRange.right())) {
+                (cell.column() <= printRange.right())) {
             painter.setPen(cell.sheet()->map()->settings()->pageBorderColor());
             line = QLineF(coordinate.x(),  coordinate.y(),
                           coordinate.x() + d->width, coordinate.y());
@@ -1193,7 +1200,7 @@ void CellView::paintPageBorders(QPainter& painter, const QPointF& coordinate,
 
         if (paintBorder & RightBorder) {
             if (print->isColumnOnNewPage(cell.column() + 1)
-                && cell.row() <= printRange.bottom()) {
+                    && cell.row() <= printRange.bottom()) {
                 painter.setPen(cell.sheet()->map()->settings()->pageBorderColor());
 
                 if (cell.sheet()->layoutDirection() == Qt::RightToLeft)
@@ -1208,7 +1215,7 @@ void CellView::paintPageBorders(QPainter& painter, const QPointF& coordinate,
 
         if (paintBorder & BottomBorder) {
             if (print->isRowOnNewPage(cell.row() + 1)
-                && cell.column() <= printRange.right()) {
+                    && cell.column() <= printRange.right()) {
                 painter.setPen(cell.sheet()->map()->settings()->pageBorderColor());
                 line = QLineF(coordinate.x(),  coordinate.y() + d->height,
                               coordinate.x() + d->width, coordinate.y() + d->height);
@@ -1414,7 +1421,7 @@ QString CellView::textDisplaying(const QFontMetricsF& fm, const Cell& cell)
         start = qMin(d->displayText.length(), start);
         // Start out with the whole text, cut one character at a time, and
         // when the text finally fits, return it.
-        for (int i = start; i != 0; i--) {
+        for (int i = start; i >= 0; i--) {
             //Note that numbers are always treated as left-aligned since if we have to cut digits off, they should
             //always be the least significant ones at the end of the string
             if (hAlign == Style::Left || hAlign == Style::HAlignUndefined || isNumeric)
@@ -1546,7 +1553,7 @@ void CellView::makeLayout(SheetView* sheetView, const Cell& cell)
             font.setPointSizeF(siz / 2.);
             fontMetrics = QFontMetricsF(font, &device);
             d->calculateTextSize(font, fontMetrics);
-            if (d->fittingWidth)\
+            if (d->fittingWidth)
                 lower = siz;
             else
                 upper = siz - 1;
@@ -1658,33 +1665,19 @@ void CellView::textOffset(const QFontMetricsF& fontMetrics, const Cell& cell)
         if (!tmpVerticalText && !tmpMultiRow && !tmpAngle && !tmpRichText) {
             d->textY = effBottom;
         } else if (tmpAngle != 0) {
-            // Is enough place available?
-            if (effBottom - effTop - d->textHeight > 0) {
-                if (tmpAngle < 0) {
-                    d->textY = effBottom - d->textHeight;
-                } else {
-                    d->textY = effBottom - d->textHeight + ascent * ::cos(tmpAngle * M_PI / 180);
-                }
-                if (tmpAngle < -90 || tmpAngle > 90) {
-                    d->textY += ascent * ::cos(tmpAngle * M_PI / 180);
-                }
+            if (tmpAngle < 0) {
+                d->textY = effBottom - d->textHeight;
             } else {
-                if (tmpAngle < 0) {
-                    d->textY = effTop;
-                } else {
-                    d->textY = effTop + ascent * ::cos(tmpAngle * M_PI / 180);
-                }
+                d->textY = effBottom - d->textHeight + ascent * ::cos(tmpAngle * M_PI / 180);
+            }
+            if (tmpAngle < -90 || tmpAngle > 90) {
+                d->textY += ascent * ::cos(tmpAngle * M_PI / 180);
             }
         } else if (tmpRichText) {
             d->textY = effBottom;
         } else if (tmpMultiRow && !tmpVerticalText) {
-            // Is enough place available?
-            if (effBottom - effTop - d->textHeight > 0) {
-                d->textY = effBottom - d->textHeight + ascent;
-            } else {
-                d->textY = effTop + ascent;
-            }
-        } else {
+            d->textY = effBottom - d->textHeight + ascent;
+        } else { // vertical text
             // Is enough place available?
             if (effBottom - effTop - d->textHeight > 0) {
                 d->textY = effBottom - d->textHeight + ascent;
@@ -1857,7 +1850,16 @@ void CellView::obscureVerticalCells(SheetView* sheetView, const Cell& masterCell
         while (status == Undefined) {
             Cell nextCell = Cell(masterCell.sheet(), masterCell.column(), row + 1).masterCell();
 
-            if (nextCell.isEmpty()) {
+            bool isEmpty = true;
+            
+            for (int col = 0; col < masterCell.mergedXCells() + d->obscuredCellsX+1; col++) {
+                Cell cellNext = Cell(masterCell.sheet(), masterCell.column() + col, row + 1).masterCell();
+                if (!cellNext.isEmpty()) {
+                    isEmpty = false;
+                    break;
+                }
+            }
+            if (isEmpty) {
                 extraHeight += nextCell.height();
                 row += 1 + nextCell.mergedYCells();
 
@@ -1900,10 +1902,11 @@ void CellView::drawText(QPainter& painter, const QPointF& location, const QStrin
     const QTextOption options = d->textOptions();
 
     const bool tmpVerticalText = d->style.verticalText();
-    const qreal lineWidth = tmpVerticalText ? fontMetrics.maxWidth() :
-                                        (d->width - 2 * s_borderSpace
-                                        - 0.5 * d->style.leftBorderPen().width()
-                                        - 0.5 * d->style.rightBorderPen().width());
+    const bool tmpAngled = fixAngle(d->style.angle()) != 0;
+    const qreal lineWidth = tmpAngled ? 1e9 : tmpVerticalText ? fontMetrics.maxWidth() :
+                            (d->width - 2 * s_borderSpace
+                             - 0.5 * d->style.leftBorderPen().width()
+                             - 0.5 * d->style.rightBorderPen().width());
 
     qreal offset = 1.0 - fontMetrics.ascent();
     for (int i = 0; i < textLines.count(); ++i) {
@@ -1921,7 +1924,7 @@ void CellView::drawText(QPainter& painter, const QPointF& location, const QStrin
             line.setLineWidth(lineWidth);
             height += leading;
             line.setPosition(QPointF((s_borderSpace + 0.5 * d->style.leftBorderPen().widthF()),
-                                    height));
+                                     height));
 
             height += line.height() + lineSpacing;
         }
