@@ -26,11 +26,16 @@
 
 #include "KWPageStyle.h"
 
+#include <KoRTree.h>
+
 class KWDocument;
 class KoOdfWriteStore;
 class KoEmbeddedDocumentSaver;
 class KoGenStyles;
 class KWTextFrameSet;
+class KWPage;
+
+class KoGenChanges;
 
 /**
  * Class that has a lot of the OpenDocument (ODF) saving code for KWord.
@@ -55,15 +60,24 @@ public:
      *  @brief Writes an OASIS OpenDocument to a store.
      *  This implements the KoDocument::saveOdf method.
      */
-    bool save(KoOdfWriteStore & odfStore, KoEmbeddedDocumentSaver & embeddedSaver);
+    bool save(KoOdfWriteStore &odfStore, KoEmbeddedDocumentSaver &embeddedSaver);
 
 private:
-    QByteArray serializeHeaderFooter(KoEmbeddedDocumentSaver& embeddedSaver, KoGenStyles& mainStyles, KWTextFrameSet* fs);
-    void saveHeaderFooter(KoEmbeddedDocumentSaver& embeddedSaver, KoGenStyles& mainStyles);
+    QByteArray serializeHeaderFooter(KoEmbeddedDocumentSaver &embeddedSaver, KoGenStyles &mainStyles, KoGenChanges &changes, KWTextFrameSet* fs);
+    void saveHeaderFooter(KoEmbeddedDocumentSaver &embeddedSaver, KoGenStyles &mainStyles, KoGenChanges &changes);
+
+    void calculateZindexOffsets();
+    void addShapeToTree(KoShape *shape);
+
+    bool saveOdfSettings(KoStore *store);
 
     /// The KWord document.
     KWDocument *m_document;
-    QHash<KWPageStyle, QString> masterPages;
+    QHash<KWPageStyle, QString> m_masterPages;
+    /// Since ODF requires zindexes >= 0 and we can have negative ones we will calculate an offset per
+    /// page and store that here.
+    QHash<KWPage, int> m_zIndexOffsets;
+    KoRTree<KoShape *> m_shapeTree;
 };
 
 #endif
