@@ -66,10 +66,15 @@ void KWFrameLayout::createNewFramesForPage(int pageNumber)
     // create page background
     KWTextFrameSet *fs = getOrCreate(KWord::PageBackgroundFrameSet, page);
     if (!hasFrameOn(fs, pageNumber)) {
-        KoShape *shape = new KWPageBackground();
-        shape->setSize(QSizeF(page.width(), page.height()));
-        KWFrame *f = new KWFrame(shape, fs);
-        f->setTextRunAround(KWord::RunThrough);
+        KWFrame *frame = 0;
+        if (fs->frameCount() == 0) {
+            KoShape *shape = new KWPageBackground();
+            frame = new KWFrame(shape, fs);
+        }
+        else {
+            frame = createCopyFrame(fs, page);
+        }
+        frame->setTextRunAround(KWord::RunThrough);
     }
 
     // create headers & footers
@@ -320,18 +325,21 @@ void KWFrameLayout::layoutFramesOnPage(int pageNumber)
         default:;
         }
     }
-    if (minZIndex < INT_MAX) {
-        --minZIndex;
-        if (endnote)
-            endnote->shape()->setZIndex(minZIndex--);
-        for (int i = 0; i < columns; ++i)
-            main[i]->shape()->setZIndex(minZIndex);
-        if (footer)
-            footer->shape()->setZIndex(--minZIndex);
-        if (header)
-            header->shape()->setZIndex(--minZIndex);
-        if (pageBackground)
-            pageBackground->shape()->setZIndex(--minZIndex);
+    for (int i = 0; i < columns; ++i) {
+        main[i]->shape()->setZIndex(SHRT_MIN + 3);
+
+     }
+    if (footer) {
+        footer->shape()->setZIndex(SHRT_MIN + 2);
+    }
+    if (endnote) {
+        endnote->shape()->setZIndex(SHRT_MIN + 4);
+    }
+    if (header) {
+        header->shape()->setZIndex(SHRT_MIN + 1);
+    }
+    if (pageBackground) {
+        pageBackground->shape()->setZIndex(SHRT_MIN);
     }
 
     // spread space across items.
