@@ -197,6 +197,7 @@ public:
     KAction *showFileVersions;
     KAction *importFile;
     KAction *exportFile;
+    KToggleAction *toggleDockers;
     KRecentFilesAction *recent;
 
     bool isImporting;
@@ -338,6 +339,14 @@ KoMainWindow::KoMainWindow(const KComponentData &componentData)
     sep->setSeparator(true);
     d->splitViewActionList.append(sep);
 
+    d->toggleDockers = new KToggleAction(i18n("Show Dockers"), this);
+    d->toggleDockers->setCheckedState(KGuiItem(i18n("Hide Dockers")));
+    d->toggleDockers->setChecked(true);
+    actionCollection()->addAction("view_toggledockers", d->toggleDockers);
+
+    d->toggleDockers->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_H));
+    connect(d->toggleDockers, SIGNAL(toggled(bool)), SLOT(toggleDockersVisibility(bool)));
+
     d->dockWidgetMenu  = new KActionMenu(i18n("Dockers"), this);
     actionCollection()->addAction("settings_dockers_menu", d->dockWidgetMenu);
     d->dockWidgetMenu->setVisible(false);
@@ -1321,7 +1330,15 @@ KoPrintJob* KoMainWindow::exportToPdf(QString pdfFileName)
         if (dialog.exec() != QDialog::Accepted)
             return 0;
         KUrl url(dialog.selectedUrl());
-        // TODO warn when overwriting
+        if (KIO::NetAccess::exists(url,  KIO::NetAccess::DestinationSide, this)) {
+            bool overwrite = KMessageBox::questionYesNo(this,
+                                            i18n("A document with this name already exists.\n"\
+                                                "Do you want to overwrite it?"),
+                                            i18n("Warning")) == KMessageBox::Yes;
+            if (!overwrite) {
+                return 0;
+            }
+        }
         pdfFileName = url.toLocalFile();
     }
 
@@ -1512,7 +1529,7 @@ void KoMainWindow::slotProgress(int value)
     if (d->firstTime) {
         // The statusbar might not even be created yet.
         // So check for that first, and create it if necessary
-        QStatusBar* bar = qFindChild<QStatusBar *>(this);
+        QStatusBar *bar = findChild<QStatusBar *>();
         if (!bar) {
             statusBar()->show();
             QApplication::sendPostedEvents(this, QEvent::ChildAdded);
@@ -1886,7 +1903,6 @@ KoDockerManager * KoMainWindow::dockerManager() const
 void KoMainWindow::toggleDockersVisibility(bool v) const
 {
     Q_UNUSED(v);
-    qDebug() << "toggleDockersVisibility";
     if (d->hiddenDockwidgets.isEmpty()){
         foreach(QObject* widget, children()) {
             if (widget->inherits("QDockWidget")) {
