@@ -30,9 +30,9 @@
 
 
 VectorToolFactory::VectorToolFactory(QObject *parent)
-  : KoToolFactory(parent, "VectorToolFactory_ID", i18n("Vector tool"))
+  : KoToolFactoryBase(parent, "VectorToolFactory_ID", i18n("Vector image tool"))
 {
-    setToolTip (i18n("EMF editing tool"));
+    setToolTip (i18n("Vector image selection tool"));
     setToolType (dynamicToolType());
 
     //setIcon ("");
@@ -44,10 +44,10 @@ VectorToolFactory::~VectorToolFactory()
 {
 }
 
-KoTool * VectorToolFactory::createTool(KoCanvasBase *canvas)
+KoToolBase * VectorToolFactory::createTool(KoCanvasBase *canvas)
 {
     return new VectorTool(canvas);
 }
 
 
-#include "VectorToolFactory.moc"
+#include <VectorToolFactory.moc>
